@@ -427,7 +427,7 @@ def compile_dataframe_for_all_datasets_on_metric(openmlids, metric):
 
 
 def get_all_curves_for_metric(metric="accuracy"):
-    supported_metrics = ["accuracy", "logloss"]:
+    supported_metrics = ["accuracy", "logloss"]
     if not metric in supported_metrics:
         raise ValueError(f"Unsupported metric {metric}. Supported metrics are {supported_metrics}")
     return pd.read_csv(StringIO(pkg_resources.read_text('lcdb', f'database-{metric}.csv')))
\ No newline at end of file
